\center
**In partial fulfillment of the academic requirements of this co-op term**

\fbox{\begin{minipage}{12cm}
This report will be handled by UVic Co-op staff and will be read by 
one assigned report marker who may be a co-op
staff member within the Engineering and Computer Science Co-operative Education Program, or a UVic faculty member or
teaching assistant. The report will be retained and available to the student or, subject to the student's right to 
appeal a grade, held for one year after which it will be deleted.
\end{minipage}}

\ 


**Signature**: _______________________________________

**Position**: ________________________________________

**Date**: __________________________________________

**Name(print)**: _____________________________________

**E-mail**: _________________________________________

**For (Company Name)**: _______________________________

\raggedright

\thispagestyle{empty}
\clearpage
\pagenumbering{roman}

\renewcommand{\thesection}{}
\renewcommand{\thesubsection}{\arabic{subsection}}

\pagebreak
